# coding: utf-8
import argparse
from .asciiart import AsciiArt


def init():
    parser = argparse.ArgumentParser()
    parser.add_argument('file')
    parser.add_argument('-s', '--scaling_ratio', help="set scaling ratio", type=float, default=0.5)
    parser.add_argument('-o', '--output_format', help="set output format", type=int, default=1)
    parser.add_argument('-fs', '--font_size', help="set font size", type=int, default=5)
    parser.add_argument('-lh', '--line_height', help="set line height", type=float, default=0.65)

    args = parser.parse_args()
    return args.file, args.scaling_ratio, args.output_format, args.font_size, args.line_height


def main():
    img_path, scaling_ratio, output_format, font_size, line_height = init()
    asciiart = AsciiArt()
    if output_format == 0:
        asciiart.convert(filepath=img_path,
                         target_format="txt",
                         scaling_ratio=scaling_ratio)
    elif output_format == 1:
        asciiart.convert(filepath=img_path,
                         target_format="html",
                         scaling_ratio=scaling_ratio,
                         font_size=font_size,
                         line_height=line_height)
    elif output_format == 2:
        asciiart.convert(filepath=img_path,
                         target_format="txt",
                         scaling_ratio=scaling_ratio)
        asciiart.convert(filepath=img_path,
                         target_format="html",
                         scaling_ratio=scaling_ratio,
                         font_size=font_size,
                         line_height=line_height)
    else:
        raise ValueError('Possible values are 0, 1 and 2.')


if __name__ == '__main__':
    main()



import os
import sys
import pyascii
from setuptools import setup

# "setup.py publish" shortcut.
if sys.argv[-1] == 'publish':
    os.system('python setup.py sdist')
    os.system('twine upload dist/*')
    # os.system('rm -rf dist pyascii.egg-info')  # for Linux
    os.system('rm –path dist, pyascii.egg-info –recurse –force')  # for Windows
    sys.exit()

setup(
    name='pyascii',
    version=pyascii.__version__,
    description="A tool for converting images or videos to ASCII.",
    keywords='asciiart',
    url='https://github.com/zhoudaxia233/PyAscii',
    license='MIT',
    packages=['pyascii'],
    include_package_data=True,
    zip_safe=False,
    install_requires=['Pillow>=5.1.0'],
    python_requires='>=3.6',
    dependency_links=[],
    entry_points={
        'console_scripts': [
            'pyascii=pyascii.main:main',
        ]
    }

)



# coding: utf-8
from PIL import Image


class AsciiArt:
    def __init__(self):
        self.gray_scale = r'@%#*+=-:. '
        self.num_of_color_levels = len(self.gray_scale)

    def convert(self, filepath, target_format, scaling_ratio, font_size=None, line_height=None):
        image = Image.open(filepath)
        filename = filepath.split('.')[0]

        ascii_data = self.__img_to_ascii(image, scaling_ratio)

        if target_format == "txt":
            self.save_as_txt_file(ascii_data, filename)
        elif target_format == "html":
            self.save_as_html_file(ascii_data, font_size, line_height, filename)
        else:
            print(f'{target_format} is not supported.')

    def __select_ascii_char(self, pixel):
        unit = 256 / self.num_of_color_levels
        return self.gray_scale[int(pixel/unit)]

    def __img_to_ascii(self, image, scaling_ratio):
        image = image.convert('L')
        width, height = image.size
        image = image.resize((int(width*scaling_ratio), int(height*scaling_ratio)), Image.LANCZOS)

        width_new, height_new = image.size
        ascii_data = ''
        for row in range(height_new):
            for col in range(width_new):
                pixel = image.getpixel((col, row))
                ascii_data += self.__select_ascii_char(pixel)
            ascii_data += '\n'
        return ascii_data

    @staticmethod
    def save_as_txt_file(ascii_data, output_filename):
        with open(f'{output_filename}.txt', 'w') as f:
            f.write(ascii_data)

    @staticmethod
    def save_as_html_file(ascii_data, font_size, line_height, output_filename):
        html = '''<!DOCTYPE HTML>
                <html>
                <head>
                <meta http-equiv="content-type" content="text/html; charset=utf-8" />
                <style type="text/css">
                    pre {
                    word-wrap: break-word;      /* IE 5.5-7 */
                    white-space: -moz-pre-wrap; /* Firefox 1.0-2.0 */
                    white-space: pre-wrap;      /* Modern browsers */
                    font-family: 'Monaco', 'Consolas', monospace;
                    line-height: %.2f;
                    font-size: %dpx;
                    }
                </style>
                </head>
                <body>
                <pre>%s</pre>
                </body>
                </html>
                '''
        html = html % (line_height, font_size, ascii_data)
        with open(f'{output_filename}.html', 'w') as f:
            f.write(html)
